==> drupal-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/drupal/core/modules/views/tests/src/Kernel/Plugin/SqlEntityLoadingTest.php <==
<?php

namespace Drupal\Tests\views\Kernel\Plugin;

use Drupal\node\Entity\Node;
use Drupal\node\Entity\NodeType;
use Drupal\Tests\views\Kernel\ViewsKernelTestBase;
use Drupal\views\Views;

/**
 * Tests the loading of entities and entity revisions.
 *
 * @group views
 *
 * @see \Drupal\views\Plugin\views\query\Sql
 */
class SqlEntityLoadingTest extends ViewsKernelTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = ['node', 'user'];

  /**
   * {@inheritdoc}
   */
  public static $testViews = ['base_and_revision'];

  /**
   * {@inheritdoc}
   */
  protected function setUp($import_test_views = TRUE) {
    parent::setUp($import_test_views);

    $this->installEntitySchema('node');
    $this->installEntitySchema('user');
    $this->installSchema('node', 'node_access');
  }

  public function testViewWithNonDefaultForwardRevision() {
    $node_type = NodeType::create([
      'type' => 'page',
    ]);
    $node_type->save();

    $node = Node::create([
      'type' => 'page',
      'title' => 'test title',
    ]);
    $node->save();

    // Creates the first revision, which is set as default.
    $revision = clone $node;
    $revision->setNewRevision(TRUE);
    $revision->isDefaultRevision(TRUE);
    $revision->save();

    // Creates the second revision, which is not set as default.
    $revision2 = clone $node;
    $revision2->setNewRevision(TRUE);
    $revision2->isDefaultRevision(FALSE);
    $revision2->save();

    $view = Views::getView('base_and_revision');
    $view->execute();

    $expected = [
      [
        'nid' => $node->id(),
        // The default revision ID.
        'vid_1' => $revision->getRevisionId(),
        // THe latest revision ID.
        'vid' => $revision2->getRevisionId(),
      ],
    ];
    $this->assertIdenticalResultset($view, $expected, [
      'node_field_data_node_field_revision_nid' => 'nid',
      'vid_1' => 'vid_1',
      'vid' => 'vid',
    ]);
  }

}

==> drupal-8.5.6-1-any.pkg.tar.xz: usr/share/webapps/drupal/core/modules/views/tests/src/Kernel/Plugin/SqlEntityLoadingTest.php <==
<?php

namespace Drupal\Tests\views\Kernel\Plugin;

use Drupal\node\Entity\Node;
use Drupal\node\Entity\NodeType;
use Drupal\Tests\views\Kernel\ViewsKernelTestBase;
use Drupal\views\Views;

/**
 * Tests the loading of entities and entity revisions.
 *
 * @group views
 *
 * @see \Drupal\views\Plugin\views\query\Sql
 */
class SqlEntityLoadingTest extends ViewsKernelTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = ['node', 'user'];

  /**
   * {@inheritdoc}
   */
  public static $testViews = ['base_and_revision'];

  /**
   * {@inheritdoc}
   */
  protected function setUp($import_test_views = TRUE) {
    parent::setUp($import_test_views);

    $this->installEntitySchema('node');
    $this->installEntitySchema('user');
    $this->installSchema('node', 'node_access');
  }

  public function testViewWithNonDefaultPendingRevision() {
    $node_type = NodeType::create([
      'type' => 'page',
    ]);
    $node_type->save();

    $node = Node::create([
      'type' => 'page',
      'title' => 'test title',
    ]);
    $node->save();

    // Creates the first revision, which is set as default.
    $revision = clone $node;
    $revision->setNewRevision(TRUE);
    $revision->isDefaultRevision(TRUE);
    $revision->save();

    // Creates the second revision, which is not set as default.
    $revision2 = clone $node;
    $revision2->setNewRevision(TRUE);
    $revision2->isDefaultRevision(FALSE);
    $revision2->save();

    $view = Views::getView('base_and_revision');
    $view->execute();

    $expected = [
      [
        'nid' => $node->id(),
        // The default revision ID.
        'vid_1' => $revision->getRevisionId(),
        // THe latest revision ID.
        'vid' => $revision2->getRevisionId(),
      ],
    ];
    $this->assertIdenticalResultset($view, $expected, [
      'node_field_data_node_field_revision_nid' => 'nid',
      'vid_1' => 'vid_1',
      'vid' => 'vid',
    ]);
  }

}
